package com.jeethink.manage.service;

import com.jeethink.bean.domain.ArchivesMaster;
import com.jeethink.bean.vo.Approval;
import com.jeethink.receive.vo.ArchivesVO;

import java.util.List;

/**
 * 销毁清册Service接口
 * 
 * @author zjt
 * @date 2022-11-10
 */
public interface IDestroyService
{
    /**
     * 查询销毁清册列表
     * 
     * @param archives 销毁清册
     * @return 销毁清册集合
     */
    List<ArchivesMaster> selectDestroyList(ArchivesMaster archives);

    void applyDestroy(String archivesId);

    void approvalDestroy(Approval approval);

    ArchivesVO seelectArchivesById(String archivesId);

    void revocationDestroy(String archivesId);
}
